"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const theme_check_common_1 = require("@shopify/theme-check-common");
const vitest_1 = require("vitest");
const DiagnosticsManager_1 = require("./DiagnosticsManager");
const offenseToDiagnostic_1 = require("./offenseToDiagnostic");
(0, vitest_1.describe)('Module: DiagnosticsManager', () => {
    let diagnosticsManager;
    let connection;
    (0, vitest_1.beforeEach)(() => {
        connection = {
            sendDiagnostics: vitest_1.vi.fn(),
        };
        diagnosticsManager = new DiagnosticsManager_1.DiagnosticsManager(connection);
    });
    (0, vitest_1.it)('should send diagnostics on set', () => {
        const fileURI = 'browser:///input.liquid';
        const fileVersion = 0;
        const offenses = [
            {
                absolutePath: '/input.liquid',
                message: 'Test',
                check: 'TestCheck',
                start: {
                    character: 0,
                    line: 0,
                    index: 0,
                },
                end: {
                    character: 10,
                    line: 0,
                    index: 10,
                },
                severity: 0,
                type: theme_check_common_1.SourceCodeType.LiquidHtml,
            },
        ];
        const diagnostics = offenses.map(offenseToDiagnostic_1.offenseToDiagnostic);
        diagnosticsManager.set(fileURI, fileVersion, offenses);
        (0, vitest_1.expect)(connection.sendDiagnostics).toBeCalledWith({
            uri: fileURI,
            version: fileVersion,
            diagnostics,
        });
    });
    (0, vitest_1.it)('should sendDiagnostics with an empty array on clear', () => {
        const fileURI = 'browser:///input.liquid';
        const fileVersion = 0;
        const offenses = [
            {
                absolutePath: '/input.liquid',
                message: 'Test',
                check: 'TestCheck',
                start: {
                    character: 0,
                    line: 0,
                    index: 0,
                },
                end: {
                    character: 10,
                    line: 0,
                    index: 10,
                },
                severity: 0,
                type: theme_check_common_1.SourceCodeType.LiquidHtml,
            },
        ];
        diagnosticsManager.set(fileURI, fileVersion, offenses);
        diagnosticsManager.clear(fileURI);
        (0, vitest_1.expect)(connection.sendDiagnostics).toBeCalledTimes(2);
        (0, vitest_1.expect)(connection.sendDiagnostics).toHaveBeenLastCalledWith({
            uri: fileURI,
            diagnostics: [],
        });
    });
});
//# sourceMappingURL=DiagnosticsManager.spec.js.map