"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompletionItemsAssertion = void 0;
exports.CompletionItemsAssertion = {
    name: 'complete',
    fn: async function (...args) {
        const provider = this._obj;
        const context = args.at(0);
        const expected = args.at(1);
        const source = createSourceCode(context);
        const completionParams = createCompletionParams(context);
        provider.documentManager.open(completionParams.textDocument.uri, source, 1);
        const actual = await provider.completions(completionParams);
        const isEmptyListAssertion = expected.length === 0;
        if (isEmptyListAssertion) {
            emptyListAssertion(this, actual, expected);
            return;
        }
        const isLabelAssertion = typeof expected.at(0) === 'string';
        if (isLabelAssertion) {
            labelAssertion(this, actual, expected);
            return;
        }
        objectAssertion(this, actual, expected);
    },
};
function emptyListAssertion(chai, actual, expected) {
    const actualJson = JSON.stringify(actual, null, 2);
    chai.assert(expected.length === actual.length, `expected ${actualJson} to be empty`, `expected ${actualJson} to not be empty`, expected, actual, false);
}
function labelAssertion(chai, actual, expectedLabels) {
    objectAssertion(chai, actual.map((e) => e.label), expectedLabels);
}
function objectAssertion(chai, actual, expected) {
    const actualJson = JSON.stringify(actual, null, 2);
    const expectedJson = JSON.stringify(expected, null, 2);
    chai.assert(actualJson === expectedJson, `expected ${actualJson} to be ${expectedJson}`, `expected ${actualJson} to not be ${expectedJson}`, expectedJson, actualJson, false);
}
function createSourceCode(context) {
    const regex = new RegExp('█', 'g');
    return context.replace(regex, '');
}
function createCompletionParams(context) {
    const position = createPosition(context);
    const textDocument = { uri: '/path/to/file.liquid' };
    return {
        position,
        textDocument,
    };
}
function createPosition(context) {
    const index = context.indexOf('█');
    const lines = context.substring(0, index === -1 ? context.length : index).split('\n');
    const line = lines.length - 1;
    const character = lines[line].length;
    return { line, character };
}
//# sourceMappingURL=CompletionItemsAssertion.js.map